#[non_exhaustive]pub enum AuthError {
MissingCredentials,
InvalidCredentials,
Unauthorized,
}Expand description
A failure to authenticate or authorize a request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingCredentials
No credentials were presented but the deployment requires them.
InvalidCredentials
Credentials were presented but are not valid.
The principal is authenticated but not permitted the action.
Implementations