pub struct InjectedField {
pub name: FieldName,
pub value: InjectedValue,
}Expand description
A field the proxy injects into every ingested document (and strips on read).
The field name is chosen by the implementer (per the requirement that the
SPI decides injected field names). The value is computed per-document from
InjectedValue.
Fields
name: FieldNameThe name of the field to inject.
value: InjectedValueHow to compute the field’s value.
Implementations
Sourceimpl InjectedField
impl InjectedField
Sourcepub fn new(name: FieldName, value: InjectedValue) -> Self
pub fn new(name: FieldName, value: InjectedValue) -> Self
Constructs an injected field.